Phys. Rev. X 12, 041027 (2022) - Tearing Instability and Current-Sheet Disruption in the Turbulent Dynamo
Description: Turbulent dynamos efficiently generate folded magnetic fields that, at small plasma resistivity and viscosity, are disrupted by resistive tearing and plasmoid formation.
Date: 2022-12-09

- Open Access

### Tearing Instability and Current-Sheet Disruption in the Turbulent Dynamo

##### Alisa K. Galishnikova, Matthew W. Kunz, and Alexander A. Schekochihin

##### Phys. Rev. X 12, 041027 – Published 9 December 2022

More
×

- Article
- References
- Citing Articles (10)

PDF HTML Export Citation

  Abstract
  Authors
  Popular Summary
  Article Text

- INTRODUCTION
- THEORETICAL CONSIDERATIONS
- NUMERICAL RESULTS
- SUMMARY AND OUTLOOK
- ACKNOWLEDGMENTS

  References

#### Abstract

Turbulence in a conducting plasma can amplify seed magnetic fields in what is known as the turbulent, or small-scale, dynamo. The associated growth rate and emergent magnetic-field geometry depend sensitively on the material properties of the plasma, in particular on the Reynolds number Re, the magnetic Reynolds number Rm, and their ratio Pm≡Rm/Re. For Pm>1, the amplified magnetic field is gradually arranged into a folded structure, with direction reversals at the resistive scale and field lines curved at the larger scale of the flow. As the mean magnetic energy grows to come into approximate equipartition with the fluid motions, this folded structure is thought to persist. Using analytical theory and high-resolution-magnetohydrodynamics simulations with the athena++ code, we show that these magnetic folds become unstable to tearing during the nonlinear stage of the dynamo for Rm≳10 4 and Re≳10 3. An Rm- and Pm-dependent tearing scale, at and below which folds are disrupted, is predicted theoretically and found to match well the characteristic field-reversal scale measured in the simulations. The disruption of folds by tearing increases the ratio of viscous-to-resistive dissipation. In the saturated state, the magnetic-energy spectrum exhibits a sub-tearing-scale steepening to a slope consistent with that predicted for tearing-mediated Alfvénic turbulence. Its spectral peak appears to be independent of the resistive scale and comparable to the driving scale of the flow, while the magnetic energy resides in a broad range of scales extending down to the field-reversal scale set by tearing. Emergence of a degree of large-scale magnetic coherence in the saturated state of the turbulent dynamo may be consistent with observations of magnetic-field fluctuations in galaxy clusters and recent laboratory experiments.

4 More

- Received 19 January 2022
- Revised 21 September 2022
- Accepted 13 October 2022

DOI: https://doi.org/10.1103/PhysRevX.12.041027

Published by the American Physical Society under the terms of the Creative Commons Attribution 4.0 International license. Further distribution of this work must maintain attribution to the author(s) and the published article’s title, journal citation, and DOI.

Published by the American Physical Society

#### Physics Subject Headings (PhySH)

Dynamo theory Magnetohydrodynamic turbulence Space & astrophysical plasma
Plasma PhysicsGravitation, Cosmology & Astrophysics

#### Authors & Affiliations

Alisa K. Galishnikova*

- Department of Astrophysical Sciences, Princeton University, 4 Ivy Lane, Princeton, New Jersey 08544, USA

Matthew W. Kunz†

- Department of Astrophysical Sciences, Princeton University, 4 Ivy Lane, Princeton, New Jersey 08544, USA and Princeton Plasma Physics Laboratory, P.O. Box 451, Princeton, New Jersey 08543, USA

Alexander A. Schekochihin

- The Rudolf Peierls Centre for Theoretical Physics, University of Oxford, Clarendon Laboratory, Parks Road, Oxford, OX1 3PU, United Kingdom and Merton College, Oxford OX1 4JD, United Kingdom

- *alisag@princeton.edu
- †mkunz@princeton.edu

Click to Expand

#### Popular Summary

Magnetic fields are generically amplified in turbulent, conducting fluids in a process known as the turbulent, or small-scale, dynamo. This process is believed to be responsible for the dynamically important magnetic fields that are now observed in a variety of astrophysical systems. Using theoretical arguments and high-resolution magnetohydrodynamic numerical simulations, we investigate how these dynamo-generated magnetic fields are structured, placing particular emphasis on the competitive interplay between the turbulent stretching and resistive annihilation of oppositely oriented magnetic-field lines.

We find that the turbulent dynamo is an efficient generator of folded magnetic fields and that, at sufficiently small plasma resistivity and viscosity, such folds are disrupted by resistive tearing and plasmoid formation. This disruption affects the spectra and characteristic length scales of the amplified magnetic field and turbulent flow, and it modifies the nature of dissipation occurring at small scales. At sufficiently small resistivity, the spectral peak of the magnetic field occurs on a scale that appears to be independent of the material properties of the plasma, a feature long suspected theoretically and consistent with observations of intracluster magnetic fields but never before convincingly demonstrated from high-resolution simulations.

This work is part of a growing paradigm shift in which plasma turbulence and magnetic reconnection are placed on equal footing, with both contributing to determine the strength, structure, and statistics of cosmic magnetic fields. Whether or not this interplay is ultimately responsible for the degree of large-scale coherence in the magnetic field we find in the saturated state of the small-scale dynamo awaits further theoretical scrutiny and next-generation radio-telescope observations of intergalactic and intracluster magnetic fields.

Click to Expand

#### Article Text

Click to Expand

#### References

Click to Expand

##### Issue

Vol. 12, Iss. 4 — October - December 2022

##### Subject Areas

- Astrophysics
- Plasma Physics

Reuse & Permissions

#### Authorization Required

Log In

###### Other Options

- Buy Article »
- Find an Institution with the Article »

×

#### Download & Share

PDF Export Reuse & Permissions Citing Articles (10)

- Tweet

×

#### Images

- ###### Figure 1

  An illustrative sketch of a characteristic magnetic fold produced during the kinematic stage of the turbulent dynamo, with its length ℓ∥ set by the viscous scale ℓ ν and its width ℓ⊥ set by the resistive scale ℓ η. The possibility that such a fold might be disrupted by resistive tearing modes (symbolized by the red islands) in either the kinematic or the nonlinear stage of the dynamo is investigated in this paper.

  Reuse & Permissions

- ###### Figure 2

  Qualitative comparison of magnetic-field strength B (top row) and speed u (bottom row) during both the kinematic stage (a) and in saturation (b) taken at fixed Pm=10 from runs a2, b2, c2, and d2. Both quantities are normalized in each snapshot so that the color bars range linearly between their instantaneous minimum and maximum values in the domain. The resolution, and thus Rm, increases from left to right as indicated.

  Reuse & Permissions

- ###### Figure 3

  Snapshot of magnetic-field strength in the saturated state of run c7 (1120 3, Pm=500, Re≈20, Rm≈10 4). Large Pm results in elongated laminar current sheets, in contrast to those seen in run c2 [1120 3, Pm=10, Re≈10 3, Rm≈10 4; see Fig. 2]. Two 1D spatial cuts of the magnetic field are shown on the left side; colors indicate different projections of the magnetic field: in plane (blue) and out of plane (red).

  Reuse & Permissions

- ###### Figure 4

  Example of a typical current sheet during saturation for Pm=10 at resolution 560 3 (a) and 2240 3 (b) (runs b2 and d2, respectively). Color shows the magnitude of the current density; magnetic-field lines are traced by white arrows. Panel (c) shows a 3D rendering of the current density (color) in a typical plasmoid formed within a disrupted current sheet that is oriented diagonally from bottom left to top right. Magnetic-field lines (white) originate in a small area below and wrap around the central plasmoid; a slice of the current density is also displayed on the back face of the volume.

  Reuse & Permissions

- ###### Figure 5

  Angle-integrated spectra for Pm=10 at different resolutions (runs a2, b2, c2, and d2). Color coding of lines is the same in all panels. (a) Kinetic E(k) (dashed) and magnetic M(k) (solid) energy spectra at the end of the kinematic stage, normalized by ρ 0 u rms, sat 2. The spectral peak of the magnetic energy depends on the resolution. (b) Kinetic E(k) (dashed) and magnetic- M(k) (solid) energy spectra normalized by ρ 0 u rms, sat 2, time averaged over the saturated state. The arrows indicate the predicted field-reversal scale λ*−1 [see Eq. (10)] for Pm=10 at 1120 3 (purple) and 2240 3 (black). The magnetic-energy spectrum acquires a slope steeper than −5/3 starting at k/2 π∼λ*−1, which at 2240 3 is consistent with the spectral envelope of k−19/9 expected for a tearing-mediated cascade. The spectral peak of the magnetic energy appears to be independent of Rm. (c) Transfer function T(k) in saturation, normalized by ρ 0 u rms, sat 3, with filled (open) circles corresponding to work done by (against) the Lorentz force.

  Reuse & Permissions

- ###### Figure 6

  (a) Angle-integrated kinetic E(k) (dashed) and magnetic M(k) (solid) spectra, time averaged over the saturated state of runs d1, d2, d3, and d4 (2240 3 at different Pm), normalized by ρ 0 u rms, sat 2. The magnetic-energy spectrum steepens to be consistent with the predicted −19/9 envelope for a tearing-mediated cascade at a wave number that increases slightly with Pm; cf. Eq. (10), which predicts λ*−1∝Pm 1/5 at fixed Rm when n=2. The arrows indicate the predicted λ*−1 for Pm=10 (purple) and 100 (yellow). (b) Kinetic spectra compensated by k 5/3, and magnetic spectra compensated by k, to illustrate the argument made at the end of Sec. 3d; here, k M(k) is multiplied by an arbitrary factor of 0.1 to separate it visually from the other curves.

  Reuse & Permissions

- ###### Figure 7

  Time evolution of the field-reversal scale k B×J−1 during the nonlinear stage at resolution 2240 3 for different Pm (runs d1, d2, d3, d4) and at resolution 1120 3 with Pm=500 (run c7; here, k B×J is multiplied by an arbitrary factor of 1.4 to bring it nearer visually to the other curves).

  Reuse & Permissions

- ###### Figure 8

  Dependence of the field-reversal wave number k B×J on plasma parameters in the saturated state. (a),(b) k B×J vs Pm at different Rm; the color coding is the same for these two panels. In (a), k B×J is divided by Rm 1/2, the predicted Rm dependence of the inverse resistive scale ℓ η−1; in (b), k B×J is divided by Rm 3/10, the predicted Rm dependence of the inverse tearing scale λ*−1 [see Eq. (10)]. (c) k B×J vs Rm at different Pm. Low-Rm runs show an Rm dependence consistent with the resistive scale k B×J∼2 π/ℓ η; high-Rm runs show an Rm and Pm dependence consistent with the predicted tearing scale k B×J∼2 π/λ*.

  Reuse & Permissions

- ###### Figure 9

  Time evolution of the characteristic wave numbers (k∥,k B·J, k B×J) describing the magnetic field [see Eq. (19)] and k u describing the small-scale structure of the velocity field [see Eq. (20)] at Pm=10 and resolutions 560 3 and 2240 3.

  Reuse & Permissions

- ###### Figure 10

  Dependence of (a) the integral scale k int [Eq. (21)] and (b) the energy-containing scale k EC [Eq. (22)] on Rm at the end of the kinematic stage (red markers) and in saturation (blue markers). Different markers correspond to different Pm, as indicated; the green squares refer to the saturated state of runs b2⋄ and c2⋄. At the end of the kinematic stage, both k int and k EC vary approximately as Rm 1/2, consistent with k int∼k EC∼ℓ η−1. In saturation, k int appears to approach a constant value at large Rm, at least for Pm≤50, while k EC becomes consistent with the tearing scale ∝Rm 3/10.

  Reuse & Permissions

- ###### Figure 11

  Ratio of turbulent energy dissipated viscously versus resistively in the saturated state (a) versus Pm at different resolutions (and therefore different Rm) and (b) versus Rm at different Pm. Error bars reflect the standard deviation in time.

  Reuse & Permissions

×

Sign up to receive regular email alerts from Physical Review X

#### Reuse & Permissions

It is not necessary to obtain permission to reuse this article or its components as it is available under the terms of the Creative Commons Attribution 4.0 International license. This license permits unrestricted use, distribution, and reproduction in any medium, provided attribution to the author(s) and the published article's title, journal citation, and DOI are maintained. Please note that some figures may have been included with permission from other third parties. It is your responsibility to obtain the proper permission from the rights holder directly for these figures.

×

#### Log In

Cancel

- Forgot your username/password?
- Create an account

×

#### Search

#### Article Lookup

###### Paste a citation or DOI

###### Enter a citation

Journal:
Volume:
Article:
×